==> khttrack-0.10.tar.bz2: khttrack-0.10/khttrack/khproject.h <==
/***************************************************************************
                          khproject.h  -  description
                             -------------------
    begin                : Wed Jun 26 2002
    copyright            : (C) 2002 by Stphane Chapeau
    email                : nuscly@ifrance.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KHPROJECT_H
#define KHPROJECT_H


// type par defaut
#define INT_UNKNOWN -1
#define CHAR_UNKNOWN "Unknown"
#define DEFAULT_PATH "~/websites/"

// gene_start
#define START_HOUR 0
#define START_NOW  1
#define START_SAVE 2

// Taille des chaines
#define CH_TL 512

struct KhttrackFile {

  /** Propites gnrales
  mainwizard.ui
  */
  int gene_action;
  char gene_projectInfo[CH_TL]; // MultiLineEdit2   QMultiLineEdit
  char gene_projectName[CH_TL]; // ProjectName      Qlabel
  char gene_projectPath[CH_TL]; // EditProjectPath  QLineEdit
  int  gene_start;
  int  gene_timeHour;
  int  gene_timeMin;
  int  gene_timeSec;
  char gene_url[CH_TL];         // URLEdit          QMultiLineEdit

  /** Window Options
  option.ui
  */
  // Proxy

  char    browserID_footer[CH_TL];
  char    browserID_identity[CH_TL];    // QComboBox34      QComboBox
  int    build_dosName;
  int    build_hidePasswords;
  int    build_hideQueryString;
  int    build_noErrorPages;
  int    build_noExternalPages;
  int    build_notPurges;
  int    build_personnalStruct;
  int    build_siteStructureType;
  char    build_siteStructureTypePerso[CH_TL];
  int    experts_debug;
  int    experts_primaryScanRule;
  int    experts_rewriteLinks;
  int    experts_travelMode;
  int    experts_globalTravelMode;
  int    experts_useCache;
  char    flow_minTransfert[CH_TL];
  char    flow_numConnections[CH_TL];
  char    flow_retries[CH_TL];
  char    flow_timeOut[CH_TL];
  int    flow_removeHostLow;
  int    flow_removeTimeOut;
  char    limits_maxConnexion[CH_TL];
  char    limits_maxExtDepth[CH_TL];
  char    limits_maxLinks[CH_TL];
  char    limits_maxMirrorDepth[CH_TL];
  char    limits_maxSizeHTML[CH_TL];
  char    limits_maxSizeNonHTML[CH_TL];
  char    limits_maxTime[CH_TL];
  char    limits_maxTransfer[CH_TL];
  char    limits_pauseDownload[CH_TL];
  char    limits_siteSize[CH_TL];
  int    links_detectAllLinks;
  int    links_getHTMLFirst;
  int    links_getNonHTML;
  int    links_test;
  int    log_createLog;
  int    log_makeIndex;
  int    log_redownload;
  int    log_storeAllCache;
  int    log_wordDatabase;
  int    log_logLevel;
  char    proxy_address[CH_TL];       // ComboBox1    ComboBox
  int    proxy_hidePassword;
  //int    proxy_login;
  //int    proxy_password;
  char    proxy_port[CH_TL];            // LineEdit1    QLineEdit
  int    proxy_useFtp;
  char    scanRules_filter[CH_TL];    // MultiLineEdit3 QMultiLineEdit
  int    scanRules_gif;
  int    scanRules_zip;
  int    scanRules_mov;
  int    spider_acceptCookies;
  int    spider_checkType;
  int    spider_notPuges;
  int    spider_parseJava;
  int    spider_spider;
  int    spider_tolerantRequest;
  int    spider_updateHacks;
  int    spider_http1;
  //int    mimeType_file01;
  //int    mimeType_file02;
  //int    mimeType_file03;
  //int    mimeType_file04;
  //int    mimeType_file05;
  //int    mimeType_file06;
  //int    mimeType_file07;
  //int    mimeType_file08;
  //int    mimeType_file09;
  //int    mimeType_file10;
  //int    mimeType_mime01;
  //int    mimeType_mime02;
  //int    mimeType_mime03;
  //int    mimeType_mime04;
  //int    mimeType_mime05;
  //int    mimeType_mime06;
  //int    mimeType_mime07;
  //int    mimeType_mime08;
  //int    mimeType_mime09;
  //int    mimeType_mime10;


}  ;

typedef struct KhttrackFile KhProject ;



#endif

==> khttrack-0.11.tar.bz2: khttrack-0.11/khttrack/khproject.h <==
/***************************************************************************
                          khproject.h  -  description
                             -------------------
    begin                : Wed Jun 26 2002
    copyright            : (C) 2002 by Stphane Chapeau
    email                : nuscly-devel@laposte.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KHPROJECT_H
#define KHPROJECT_H


// type par defaut
#define INT_UNKNOWN -1
#define CHAR_UNKNOWN "Unknown"
#define DEFAULT_PATH "~/websites/"

// gene_start
#define START_HOUR 0
#define START_NOW  1
#define START_SAVE 2

// Taille des chaines
#define CH_TL 512

struct KhttrackFile {

  /** Propites gnrales
  mainwizard.ui
  */
  int gene_action;
  char gene_projectInfo[CH_TL]; // MultiLineEdit2   QMultiLineEdit
  char gene_projectName[CH_TL]; // ProjectName      Qlabel
  char gene_projectPath[CH_TL]; // EditProjectPath  QLineEdit
  int  gene_start;
  int  gene_timeHour;
  int  gene_timeMin;
  int  gene_timeSec;
  char gene_url[CH_TL];         // URLEdit          QMultiLineEdit

  /** Window Options
  option.ui
  */
  // Proxy

  char    browserID_footer[CH_TL];
  char    browserID_identity[CH_TL];    // QComboBox34      QComboBox
  int    build_dosName;
  int    build_hidePasswords;
  int    build_hideQueryString;
  int    build_noErrorPages;
  int    build_noExternalPages;
  int    build_notPurges;
  int    build_personnalStruct;
  int    build_siteStructureType;
  char    build_siteStructureTypePerso[CH_TL];
  int    experts_debug;
  int    experts_primaryScanRule;
  int    experts_rewriteLinks;
  int    experts_travelMode;
  int    experts_globalTravelMode;
  int    experts_useCache;
  char    flow_minTransfert[CH_TL];
  char    flow_numConnections[CH_TL];
  char    flow_retries[CH_TL];
  char    flow_timeOut[CH_TL];
  int    flow_removeHostLow;
  int    flow_removeTimeOut;
  char    limits_maxConnexion[CH_TL];
  char    limits_maxExtDepth[CH_TL];
  char    limits_maxLinks[CH_TL];
  char    limits_maxMirrorDepth[CH_TL];
  char    limits_maxSizeHTML[CH_TL];
  char    limits_maxSizeNonHTML[CH_TL];
  char    limits_maxTime[CH_TL];
  char    limits_maxTransfer[CH_TL];
  char    limits_pauseDownload[CH_TL];
  char    limits_siteSize[CH_TL];
  int    links_detectAllLinks;
  int    links_getHTMLFirst;
  int    links_getNonHTML;
  int    links_test;
  int    log_createLog;
  int    log_makeIndex;
  int    log_redownload;
  int    log_storeAllCache;
  int    log_wordDatabase;
  int    log_logLevel;
  char    proxy_address[CH_TL];       // ComboBox1    ComboBox
  int    proxy_hidePassword;
  //int    proxy_login;
  //int    proxy_password;
  char    proxy_port[CH_TL];            // LineEdit1    QLineEdit
  int    proxy_useFtp;
  char    scanRules_filter[CH_TL];    // MultiLineEdit3 QMultiLineEdit
  int    scanRules_gif;
  int    scanRules_zip;
  int    scanRules_mov;
  int    spider_acceptCookies;
  int    spider_checkType;
  int    spider_notPuges;
  int    spider_parseJava;
  int    spider_spider;
  int    spider_tolerantRequest;
  int    spider_updateHacks;
  int    spider_http1;
  //int    mimeType_file01;
  //int    mimeType_file02;
  //int    mimeType_file03;
  //int    mimeType_file04;
  //int    mimeType_file05;
  //int    mimeType_file06;
  //int    mimeType_file07;
  //int    mimeType_file08;
  //int    mimeType_file09;
  //int    mimeType_file10;
  //int    mimeType_mime01;
  //int    mimeType_mime02;
  //int    mimeType_mime03;
  //int    mimeType_mime04;
  //int    mimeType_mime05;
  //int    mimeType_mime06;
  //int    mimeType_mime07;
  //int    mimeType_mime08;
  //int    mimeType_mime09;
  //int    mimeType_mime10;


}  ;

typedef struct KhttrackFile KhProject ;



#endif
